@@ -161,7 +161,7 @@ class CGDB:
                 element_code,
                 aggregation_code,
                 time_step_code,
-                elementMarkOverride) is None:
+                level_code) is None:
             self.create_element_context(element_code, aggregation_code, time_step_code,
                                                elementMarkOverride)
         self._data_sets_manager.create_data_set(site, element_code, aggregation_code, time_step_code, data_set_type, elementMarkOverride,)
